@@ -74,11 +74,12 @@ class Device(models.Model):
     )
 
     # A device health shows a device is ready to test or not
-    HEALTH_UNKNOWN, HEALTH_PASS, HEALTH_FAIL = range(3)
+    HEALTH_UNKNOWN, HEALTH_PASS, HEALTH_FAIL, HEALTH_LOOPING = range(4)
     HEALTH_CHOICES = (
         (HEALTH_UNKNOWN, 'Unknown'),
         (HEALTH_PASS, 'Pass'),
         (HEALTH_FAIL, 'Fail'),
+        (HEALTH_LOOPING, 'Looping'),
     )
 
     hostname = models.CharField(
@@ -147,6 +148,8 @@ class Device(models.Model):
             created_by=user, device=self, old_state=self.status,
             new_state=new_status, message=reason, job=None).save()
         self.status = new_status
+        if self.health_status == Device.HEALTH_LOOPING:
+            self.health_status = Device.HEALTH_UNKNOWN
         self.save()
 
     def put_into_online_mode(self, user, reason):
@@ -160,6 +163,17 @@ class Device(models.Model):
         self.health_status = Device.HEALTH_UNKNOWN
         self.save()
 
+    def put_into_looping_mode(self, user):
+        if self.status not in [Device.OFFLINE, Device.OFFLINING]:
+            return
+        new_status = self.IDLE
+        DeviceStateTransition.objects.create(
+            created_by=user, device=self, old_state=self.status,
+            new_state=new_status, message="Looping mode", job=None).save()
+        self.status = new_status
+        self.health_status = Device.HEALTH_LOOPING
+        self.save()
+
     #@classmethod
     #def find_devices_by_type(cls, device_type):
     #    return device_type.device_set.all()
