@@ -3,33 +3,36 @@ from django.conf.urls.defaults import url, patterns
 
 urlpatterns = patterns(
     'lava_scheduler_app.views',
-    url(r'^$', 
+    url(r'^$',
         'index',
         name='lava.scheduler'),
-    url(r'^active_jobs_json$', 
+    url(r'^active_jobs_json$',
         'index_active_jobs_json',
         name='lava.scheduler.active_jobs_json'),
-    url(r'^devices_json$', 
+    url(r'^devices_json$',
         'index_devices_json',
         name='lava.scheduler.index_devices_json'),
-    url(r'^alljobs$', 
-        'job_list', 
+    url(r'^alljobs$',
+        'job_list',
         name='lava.scheduler.job.list'),
     url(r'^alljobs_json$',
         'alljobs_json',
         name='lava.scheduler.job.list_json'),
-    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)$', 
-        'device_detail', 
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)$',
+        'device_detail',
         name='lava.scheduler.device.detail'),
-    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/recent_jobs_json$', 
-        'recent_jobs_json', 
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/recent_jobs_json$',
+        'recent_jobs_json',
         name='lava.scheduler.device.recent_jobs_json'),
-    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/transition_json$', 
-        'transition_json', 
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/transition_json$',
+        'transition_json',
         name='lava.scheduler.device.transition_json'),
-    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/maintenance$', 
-        'device_maintenance_mode', 
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/maintenance$',
+        'device_maintenance_mode',
         name='lava.scheduler.device.maintenance'),
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/looping$',
+        'device_looping_mode',
+        name='lava.scheduler.device.looping'),
     url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/online$',
         'device_online',
         name='lava.scheduler.device.online'),
@@ -64,7 +67,7 @@ urlpatterns = patterns(
         'job_cancel',
         name='lava.scheduler.job.cancel'),
     url(r'^job/(?P<pk>[0-9]+)/json$',
-        'job_json', 
+        'job_json',
         name='lava.scheduler.job.json'),
     url(r'^job/(?P<pk>[0-9]+)/output$',
         'job_output',
